summaryrefslogtreecommitdiffstats
path: root/kio/kssl/ksslcsessioncache.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kssl/ksslcsessioncache.h')
-rw-r--r--kio/kssl/ksslcsessioncache.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kio/kssl/ksslcsessioncache.h b/kio/kssl/ksslcsessioncache.h
index 839d85e06..c7a6b9a16 100644
--- a/kio/kssl/ksslcsessioncache.h
+++ b/kio/kssl/ksslcsessioncache.h
@@ -32,16 +32,16 @@ class KIO_EXPORT KSSLCSessionCache {
/**
* Store a SSL session (client side only)
* @param kurl URL the key belongs to. Method, host and port are used
* @param session QString representing session to store
*/
- static void putSessionForURL(const KURL &kurl, const QString &session);
+ static void putSessionForURL(const KURL &kurl, const TQString &session);
/**
* Retrieve a SSL session (client side only)
* @param kurl URL the key belongs to
* @return if a key can be found, QString::null otherwise
*/
- static QString getSessionForURL(const KURL &kurl);
+ static TQString getSessionForURL(const KURL &kurl);
};
#endif
@@ -32,16 +32,16 @@ class KIO_EXPORT KSSLCSessionCache {
* Store a SSL session (client side only)
* @param kurl URL the key belongs to. Method, host and port are used
- * @param session QString representing session to store
+ * @param session TQString representing session to store
*/
@@ -32,16 +32,16 @@ class KIO_EXPORT KSSLCSessionCache {
* Retrieve a SSL session (client side only)
* @param kurl URL the key belongs to
- * @return if a key can be found, QString::null otherwise
+ * @return if a key can be found, TQString::null otherwise
*/